import pytest
from setuptools_scm import format_version
from setuptools_scm_git_archive import archival_to_version


git_archival_mapping = {
    '1.0': {'ref-names': 'HEAD -> master, tag: foo, tag: 1.0'},
    '1.1': {'ref-names': 'HEAD -> master, tag: release-1.1, tag: bar'},
    '1.2': {'ref-names': 'HEAD -> master, tag: v1.2'},
}


@pytest.mark.parametrize('expected,data', sorted(git_archival_mapping.items()))
def test_archival_to_version(expected, data):
    version = archival_to_version(data)
    assert format_version(
        version,
        version_scheme='guess-next-dev',
        local_scheme='node-and-date') == expected



from os.path import dirname, join
from shutil import rmtree

from pkg_resources import DistributionNotFound, load_entry_point, working_set
from setuptools import find_packages, setup


ENTRY_GROUP = 'setuptools_scm.parse_scm'
ENTRY_GROUP_FALLBACK = 'setuptools_scm.parse_scm_fallback'
ENTRY_NAME = '.git_archival.txt'
ENTRY_POINT = ENTRY_NAME + ' = setuptools_scm_git_archive:parse'

meta = dict(
    name='setuptools_scm_git_archive',
    description='setuptools_scm plugin for git archives',
    author='Changaco',
    author_email='changaco@changaco.oy.lc',
    url='https://github.com/Changaco/setuptools_scm_git_archive/',
    license='MIT',
    packages=find_packages(),
    long_description=open(join(dirname(__file__), 'README.rst')).read(),
    keywords='scm vcs version tags git archive',
    setup_requires=['setuptools-scm'],
    entry_points={
        ENTRY_GROUP: ENTRY_POINT,
        ENTRY_GROUP_FALLBACK: ENTRY_POINT,
    },
)

# Clean up first, old eggs seem to confuse setuptools_scm
rmtree(meta['name']+'.egg-info', ignore_errors=True)

# Bootstrap
try:
    load_entry_point(meta['name'], ENTRY_GROUP, ENTRY_NAME)
except (DistributionNotFound, ImportError):
    working_set.add_entry('.')

setup(use_scm_version=True, **meta)
